@@ -4,7 +4,8 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#pragma once
+#ifndef LEADVERTISINGMANAGERTEST_H
+#define LEADVERTISINGMANAGERTEST_H
 
 #include "adapter.h"
 #include "leadvertisement.h"
@@ -35,3 +36,5 @@ private:
     TestAdvertisement *m_advertisement;
     BluezQt::AdapterPtr m_adapter;
 };
+
+#endif
